@@ -2,9 +2,8 @@ import argparse
 import json
 import traceback
 
-from explainaboard_api_client.model.system import System
-from explainaboard_api_client.model.systems_return import SystemsReturn
-from explainaboard_client import Config, ExplainaboardClient
+import explainaboard_client
+from explainaboard_client import ExplainaboardClient
 from explainaboard_client.utils import sanitize_for_json
 
 
@@ -17,23 +16,22 @@ def main():
     )
     # --- Authentication arguments
     parser.add_argument(
-        "--email",
+        "--username",
         type=str,
-        required=True,
-        help="Email address used to sign in to ExplainaBoard",
+        default=explainaboard_client.username,
+        help="Username used to sign in to ExplainaBoard. Defaults to the EB_USERNAME "
+        "environment variable.",
     )
-    parser.add_argument("--api_key", type=str, required=True, help="Your API key")
     parser.add_argument(
-        "--server",
+        "--api-key",
         type=str,
-        required=False,
-        default="main",
-        choices=["main", "staging", "local"],
-        help='Which server to use, "main" should be sufficient',
+        default=explainaboard_client.api_key,
+        help="API key for ExplainaBoard. Defaults to the EB_API_KEY environment "
+        "variable.",
     )
     # --- Query arguments
     parser.add_argument(
-        "--system_name",
+        "--system-name",
         type=str,
         help="Fuzzy match for system name",
     )
@@ -63,14 +61,14 @@ def main():
         help="Email of the creator of the system",
     )
     parser.add_argument(
-        "--shared_users",
+        "--shared-users",
         type=str,
         nargs="+",
         help="Emails of users with which the system is shared",
     )
     # ---- Display settings
     parser.add_argument(
-        "--output_format",
+        "--output-format",
         type=str,
         default="tsv",
         choices=["tsv", "json"],
@@ -83,19 +81,19 @@ def main():
         help="Which page to retrieve",
     )
     parser.add_argument(
-        "--page_size",
+        "--page-size",
         type=int,
         default=20,
         help="The number of items on each page. Set to 0 for all.",
     )
     parser.add_argument(
-        "--sort_field",
+        "--sort-field",
         type=str,
         help="Which field to sort by. Supports `created_at` and metric names "
         "(e.g. Accuracy)",
     )
     parser.add_argument(
-        "--sort_direction",
+        "--sort-direction",
         type=str,
         default="desc",
         choices=["desc", "asc"],
@@ -103,22 +101,24 @@ def main():
     )
     args = parser.parse_args()
 
-    client_config = Config(
-        args.email,
-        args.api_key,
-        args.server,
-    )
-    client = ExplainaboardClient(client_config)
-    kwargs: dict = {
-        k: v
-        for k, v in vars(args).items()
-        if (v is not None and k not in {"email", "api_key", "server", "output_format"})
-    }
+    explainaboard_client.username = args.username
+    explainaboard_client.api_key = args.api_key
+    client = ExplainaboardClient()
     try:
-        systems: SystemsReturn = client.systems_get(**kwargs)
-        system_list: list[System] = [
-            sanitize_for_json(x.to_dict()) for x in systems.systems
-        ]
+        system_list: list[dict] = client.find_systems(
+            system_name=args.system_name,
+            task=args.task,
+            dataset=args.dataset,
+            sub_dataset=args.subdataset,
+            split=args.split,
+            creator=args.creator,
+            shared_users=args.shared_users,
+            page=args.page,
+            page_size=args.page_size,
+            sort_field=args.sort_field,
+            sort_direction=args.sort_direction,
+        )
+        system_list = [sanitize_for_json(x) for x in system_list]
         if args.output_format == "json":
             print(json.dumps(system_list))
         else:
